pub enum FromReaderError {
InitializationCheckIncorrect,
Io(Error),
}Expand description
Errors that might occur deserializing a Filesystem from I/O
Variants
InitializationCheckIncorrect
All correctly initialized filesystem memory has certain bytes set for verification against memory corruption.
This error is returned when that those bytes are faulty during a read.
Io(Error)
Any failure that has to do with I/O