pub enum FromBytesError {
IncorrectSize,
InitializationCheckIncorrect,
}Expand description
Errors that might be returned from SongMemory::from_bytes()
Variants
IncorrectSize
The passed in number of bytes isn’t correct
InitializationCheckIncorrect
All correctly initialized song memory has certain bytes set for verification against memory corruption.
This error is returned when that those bytes are faulty during a read.